@@ -22,23 +22,22 @@
 #' @export
 #'
 
-metric_area <- function(x, poi = NA){
+metric_area <- function(x, poi = NULL) {
 
   # Check function arguments ----
   checkmate::assert_class(x, "RasterLayer")
-  checkmate::assert_atomic_vector(poi)
 
-  if(is.null(poi)){
+  if (is.null(poi)) {
     poi <- sort(unique(x@data@values))
   }
 
   freq_tib <- dplyr::tbl_df(raster::freq(x))
 
-  if(length(poi) == 1){
-    area_poi      <- freq_tib[freq_tib == poi,2]
+  if (length(poi) == 1) {
+    area_poi <- freq_tib[freq_tib[, 1] == poi, 2]
     area_poi_perc <- area_poi / raster::ncell(x)
   } else {
-    area_poi      <- freq_tib[freq_tib == poi,2]
+    area_poi <- freq_tib[, 2]
     area_poi_perc <- dplyr::tbl_df(area_poi / raster::ncell(x))
   }
 
@@ -47,4 +46,3 @@ metric_area <- function(x, poi = NA){
 
   return(list(Total_Area = area_poi, Proportion_Area = area_poi_perc))
 }
-
